==> vitya-0.0.4-py3-none-any.whl: vitya/pydantic_fields.py <==
from vitya import validate_inn, ValidationError, validate_kpp, validate_bic, validate_ogrn

# TODO: add tests


try:
    from pydantic import PydanticValueError
    from pydantic.typing import CallableGenerator
except ImportError:
    pass


class Inn(str):
    @classmethod
    def __get_validators__(cls) -> CallableGenerator:
        yield cls.validate

    @classmethod
    def validate(cls, value: str):
        try:
            validate_inn(value)
        except ValidationError as e:
            raise PydanticValueError() from e

        return value


class Kpp(str):
    @classmethod
    def __get_validators__(cls) -> CallableGenerator:
        yield cls.validate

    @classmethod
    def validate(cls, value: str):
        try:
            validate_kpp(value)
        except ValidationError as e:
            raise PydanticValueError() from e

        return value


class Bic(str):
    @classmethod
    def __get_validators__(cls) -> CallableGenerator:
        yield cls.validate

    @classmethod
    def validate(cls, value: str):
        try:
            validate_bic(value)
        except ValidationError as e:
            raise PydanticValueError() from e

        return value


class Ogrn(str):
    @classmethod
    def __get_validators__(cls) -> CallableGenerator:
        yield cls.validate

    @classmethod
    def validate(cls, value: str):
        try:
            validate_ogrn(value)
        except ValidationError as e:
            raise PydanticValueError() from e

        return value

==> vitya-0.0.5-py3-none-any.whl: vitya/pydantic_fields.py <==
from typing import Generator, Callable, Any

from vitya import validate_inn, ValidationError, validate_kpp, validate_bic, validate_ogrn

# TODO: add tests


try:
    from pydantic import PydanticValueError
except ImportError:
    pass

try:
    from pydantic.typing import CallableGenerator
except ImportError:
    CallableGenerator = Generator[Callable[..., Any], None, None]


class InvalidValueError(PydanticValueError):
    msg_template = 'invalid value'


class Inn(str):
    @classmethod
    def __get_validators__(cls) -> CallableGenerator:
        yield cls.validate

    @classmethod
    def validate(cls, value: str):
        try:
            validate_inn(value)
        except ValidationError as e:
            raise InvalidValueError() from e

        return value


class Kpp(str):
    @classmethod
    def __get_validators__(cls) -> CallableGenerator:
        yield cls.validate

    @classmethod
    def validate(cls, value: str):
        try:
            validate_kpp(value)
        except ValidationError as e:
            raise InvalidValueError() from e

        return value


class Bic(str):
    @classmethod
    def __get_validators__(cls) -> CallableGenerator:
        yield cls.validate

    @classmethod
    def validate(cls, value: str):
        try:
            validate_bic(value)
        except ValidationError as e:
            raise InvalidValueError() from e

        return value


class Ogrn(str):
    @classmethod
    def __get_validators__(cls) -> CallableGenerator:
        yield cls.validate

    @classmethod
    def validate(cls, value: str):
        try:
            validate_ogrn(value)
        except ValidationError as e:
            raise InvalidValueError() from e

        return value
